@@ -37,6 +37,7 @@ class dockwidget : public KSystemTray
   ~dockwidget(); 
   KPopupFrame *mypop;
   QTextView *myview;
+  bool _fPopup; // false = popup at cursor
 
   void getTranslation(const QString &szWord);
  public slots:
@@ -47,6 +48,7 @@ class dockwidget : public KSystemTray
   void done(void);
   void configure(void);
   void translate( const QString & );
+  void toggleWatchCb(void);
  protected:
   void mousePressEvent(QMouseEvent *e);
  private:
