@@ -24,7 +24,6 @@
 #include <kdatetbl.h>
 
 #include <qtextview.h>
-//#include <qtextedit.h>
 #include <qcursor.h>
 #include <qregexp.h>
 
@@ -106,6 +105,7 @@ void Engine::translate( const QString & szWord, QTextView * pView)
 
 	if ( ! szWord.isEmpty() )
 	command.append( szWord );
+//	command.append(Cb->text());
 
   //ausfuehren
   if ((fp = popen(command, "r")) == NULL) {
@@ -117,11 +117,11 @@ void Engine::translate( const QString & szWord, QTextView * pView)
 	{
 
 		//insert line break
-		//if (!first) pView->append("<BR>");
+		if (!first) pView->append("<BR>");
 		sline = line;
 		//remove numbers at the begin of line
 		sline.replace( QRegExp("\\d+\\s?.?"), "");
-      	sline=sline.stripWhiteSpace();
+      		sline=sline.stripWhiteSpace();
       	// string match for :==
       	int i = sline.find(":==");
       	if ( i > 0 )
@@ -149,7 +149,7 @@ void Engine::translate( const QString & szWord, QTextView * pView)
 
 		if (sline.contains("--- Jetzt die Kontext", TRUE))
 		{
-	  		pView->append("\n <BR><B><U>"+i18n("Context")+"</U></B><BR>");
+	  		pView->append("\n<B><U>"+i18n("Context")+"</U></B>");
 	  		nRows++;
 		}
 
@@ -159,7 +159,7 @@ void Engine::translate( const QString & szWord, QTextView * pView)
     {
     	sline = "no entry found - kein Eintrag";
 		pView->append(sline);
-		szMaxLine=sline+"HH";
+		szMaxLine=sline+"H";
     }
 
   if (ferror(fp))
@@ -183,7 +183,7 @@ void Engine::translatePopup( const QString & szWord, QTextView * pView )
   QFontMetrics fm(tFont);
 
   w = fm.width(szMaxLine)+fm.width("HHH");
-  h = fm.height()*(nRows+3);
+  h = fm.height()*(nRows+1);
 
   maxw = QApplication::desktop()->width()/2;
   maxh = QApplication::desktop()->height()/2;
