@@ -24,6 +24,8 @@
 #include <kcolorbutton.h>
 #include <kfontdialog.h>
 #include <kkeydialog.h>
+#include <qradiobutton.h>
+#include <qbuttongroup.h>
 
 /**
   *@author Michael Heidecke
@@ -40,12 +42,13 @@ public slots:
     virtual void slotOk();
 
 private:
- QFrame *f, *f2, *f3;
+ QFrame *f, *f2, *f3, *f4;
  KColorButton *Button1, *Button2, *Button3;
+ QRadioButton *rButton1, *rButton2;
+ QButtonGroup *bGroup;
  KSteak *par;
  KFontChooser *Fontchooser;
  KKeyChooser *Keychooser;
- KKeyEntryMap *mymap;
 };
 
 #endif
